..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

Flask application factories
---------------------------

.. automodule:: invenio_app.factory
    :members:

WSGI applications
-----------------

.. automodule:: invenio_app.wsgi
    :members:

.. automodule:: invenio_app.wsgi_rest
    :members:

.. automodule:: invenio_app.wsgi_ui
    :members:

Celery application factory
--------------------------

.. automodule:: invenio_app.celery
    :members:

CLI application factory
-----------------------

.. automodule:: invenio_app.cli
    :members:
